请注意

最新版本3.1.2.2023.6.19.16.57.42支持2.6, 2.7, 3.3, 3.4, 3.5, 3.6, 3.12

但我们不确定依赖库是否存在。

请使用以上版本的谨慎安装




Please note



The latest version 3.1.2.2023.6.19.16.57.42 supports 2.6, 2.7, 3.3, 3.4, 3.5, 3.6, 3.12



But we are not sure if the dependent library exists.



Please use the above version for careful installation

